@@ -17,7 +17,7 @@
 System-level utilities and helper functions.
 """
 
-import collections
+import collections.abc
 import math
 import re
 import unicodedata
@@ -59,7 +59,7 @@ _SANITIZE_KEYS = ['adminpass', 'admin_pass', 'password', 'admin_password',
                   'auth_token', 'new_pass', 'auth_password', 'secret_uuid',
                   'secret', 'sys_pswd', 'token', 'configdrive',
                   'chappassword', 'encrypted_key', 'private_key',
-                  'encryption_key_id', 'fernetkey', 'sslkey', 'passphrase',
+                  'fernetkey', 'sslkey', 'passphrase',
                   'cephclusterfsid', 'octaviaheartbeatkey', 'rabbitcookie',
                   'cephmanilaclientkey', 'pacemakerremoteauthkey',
                   'designaterndckey', 'cephadminkey', 'heatauthencryptionkey',
@@ -399,12 +399,12 @@ def mask_dict_password(dictionary, secret="***"):  # nosec
 
     """
 
-    if not isinstance(dictionary, collections.Mapping):
+    if not isinstance(dictionary, collections.abc.Mapping):
         raise TypeError("Expected a Mapping, got %s instead."
                         % type(dictionary))
     out = {}
     for k, v in dictionary.items():
-        if isinstance(v, collections.Mapping):
+        if isinstance(v, collections.abc.Mapping):
             out[k] = mask_dict_password(v, secret=secret)
             continue
         # NOTE(jlvillal): Check to see if anything in the dictionary 'key'
