@@ -17,9 +17,9 @@ import calendar
 import datetime
 import logging
 import time
+from unittest import mock
 
 import iso8601
-import mock
 from oslotest import base as test_base
 from testtools import matchers
 
@@ -39,8 +39,8 @@ class TimeUtilsTest(test_base.BaseTestCase):
         self.skynet_self_aware_time_str = '1997-08-29T06:14:00Z'
         self.skynet_self_aware_time_ms_str = '1997-08-29T06:14:00.000123Z'
         self.skynet_self_aware_time = datetime.datetime(1997, 8, 29, 6, 14, 0)
-        self.skynet_self_aware_ms_time = datetime.datetime(
-            1997, 8, 29, 6, 14, 0, 123)
+        self.skynet_self_aware_ms_time = datetime.datetime(1997, 8, 29, 6, 14,
+                                                           0, 123)
         self.one_minute_before = datetime.datetime(1997, 8, 29, 6, 13, 0)
         self.one_minute_after = datetime.datetime(1997, 8, 29, 6, 15, 0)
         self.skynet_self_aware_time_perfect_str = '1997-08-29T06:14:00.000000'
@@ -87,20 +87,18 @@ class TimeUtilsTest(test_base.BaseTestCase):
         t = timeutils.parse_strtime(s)
         self.assertEqual(orig_t, t)
 
-    def _test_is_older_than(self, fn):
-        strptime = datetime.datetime.strptime
-        with mock.patch('datetime.datetime') as datetime_mock:
-            datetime_mock.utcnow.return_value = self.skynet_self_aware_time
-            datetime_mock.strptime = strptime
-            expect_true = timeutils.is_older_than(fn(self.one_minute_before),
-                                                  59)
-            self.assertTrue(expect_true)
-            expect_false = timeutils.is_older_than(fn(self.one_minute_before),
-                                                   60)
-            self.assertFalse(expect_false)
-            expect_false = timeutils.is_older_than(fn(self.one_minute_before),
-                                                   61)
-            self.assertFalse(expect_false)
+    @mock.patch('datetime.datetime', wraps=datetime.datetime)
+    def _test_is_older_than(self, fn, datetime_mock):
+        datetime_mock.utcnow.return_value = self.skynet_self_aware_time
+        expect_true = timeutils.is_older_than(fn(self.one_minute_before),
+                                              59)
+        self.assertTrue(expect_true)
+        expect_false = timeutils.is_older_than(fn(self.one_minute_before),
+                                               60)
+        self.assertFalse(expect_false)
+        expect_false = timeutils.is_older_than(fn(self.one_minute_before),
+                                               61)
+        self.assertFalse(expect_false)
 
     def test_is_older_than_datetime(self):
         self._test_is_older_than(lambda x: x)
@@ -118,20 +116,18 @@ class TimeUtilsTest(test_base.BaseTestCase):
             tzinfo=iso8601.iso8601.FixedOffset(1, 0, 'foo')).replace(
                 hour=7))
 
-    def _test_is_newer_than(self, fn):
-        strptime = datetime.datetime.strptime
-        with mock.patch('datetime.datetime') as datetime_mock:
-            datetime_mock.utcnow.return_value = self.skynet_self_aware_time
-            datetime_mock.strptime = strptime
-            expect_true = timeutils.is_newer_than(fn(self.one_minute_after),
-                                                  59)
-            self.assertTrue(expect_true)
-            expect_false = timeutils.is_newer_than(fn(self.one_minute_after),
-                                                   60)
-            self.assertFalse(expect_false)
-            expect_false = timeutils.is_newer_than(fn(self.one_minute_after),
-                                                   61)
-            self.assertFalse(expect_false)
+    @mock.patch('datetime.datetime', wraps=datetime.datetime)
+    def _test_is_newer_than(self, fn, datetime_mock):
+        datetime_mock.utcnow.return_value = self.skynet_self_aware_time
+        expect_true = timeutils.is_newer_than(fn(self.one_minute_after),
+                                              59)
+        self.assertTrue(expect_true)
+        expect_false = timeutils.is_newer_than(fn(self.one_minute_after),
+                                               60)
+        self.assertFalse(expect_false)
+        expect_false = timeutils.is_newer_than(fn(self.one_minute_after),
+                                               61)
+        self.assertFalse(expect_false)
 
     def test_is_newer_than_datetime(self):
         self._test_is_newer_than(lambda x: x)
